==> kimageannotator_0.4.0.orig.tar.gz: kImageAnnotator-0.4.0/translations/kImageAnnotator_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Disposer</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Envoyer à l&apos;avant</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Envoyer vers l&apos;avant</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Envoyer vers l&apos;arrière</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Envoyer à l&apos;arrière</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Sélectionner ceci</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Coller</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Modifier</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationSettings</name>
    <message>
        <source>Color</source>
        <translation>Couleur</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Largeur</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Couleur du texte</translation>
    </message>
    <message>
        <source>Font Size</source>
        <translation>Taille de la police</translation>
    </message>
    <message>
        <source>Starting Number</source>
        <translation>Numéro de début</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Facteur d&apos;obfuscation</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Fermer les autres</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Tout fermer</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Fermer tous ceux de gauche</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Fermer tous ceux de droite</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Crop</source>
        <translation>Couper</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X :</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y :</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>L :</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H :</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Visibilité de la bordure et du remplissage</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Bordure et remplissage</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Bordure sans remplissage</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Ni bordure ni remplissage</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Effets d&apos;image</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Aucun effet</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>Ombre portée</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Niveaux de gris</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Bordure</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Redimensionner l&apos;image</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Conserver le ratio</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Largeur :</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Hauteur :</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Pourcentage</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Autocollant</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Sélectionner</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Crayon</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Numéro</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Marqueur rectangle</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Marqueur ellipse</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Surligneur</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texte</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Flèche</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Flèche double</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Ligne</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Flou</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectangle</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Pointeur de numéro</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Autocollant</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Pixéliser</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Pointeur de texte</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Flèche de texte</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Flèche de nombre</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomIndicator</name>
    <message>
        <source>Zoom Level</source>
        <translation>Niveau de zoom</translation>
    </message>
</context>
</TS>

==> kimageannotator_0.5.3.orig.tar.gz: kImageAnnotator-0.5.3/translations/kImageAnnotator_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Disposer</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Envoyer à l&apos;avant</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Envoyer vers l&apos;avant</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Envoyer vers l&apos;arrière</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Envoyer à l&apos;arrière</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Sélectionner ceci</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Coller</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Modifier</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation type="unfinished">Couleur</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation type="unfinished">Couleur du texte</translation>
    </message>
    <message>
        <source>Width</source>
        <translation type="unfinished">Largeur</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation type="unfinished">Facteur d&apos;obfuscation</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Fermer les autres</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Tout fermer</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Fermer tous ceux de gauche</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Fermer tous ceux de droite</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X :</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y :</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>L :</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H :</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished">Appliquer</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Visibilité de la bordure et du remplissage</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Bordure et remplissage</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Bordure sans remplissage</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Ni bordure ni remplissage</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation type="unfinished">Taille de la police</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Underline</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Effets d&apos;image</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Aucun effet</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>Ombre portée</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Niveaux de gris</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Bordure</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>Restreint</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation>Si activé, applique le canevas
pour inclure l’image d&apos;arrière-plan.</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X&#xa0;:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y&#xa0;:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>L&#xa0;:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H&#xa0;:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Appliquer</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Couleur :</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>Pivoter l&apos;image</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>90° horaire</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>90° anti-horaire</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>Aléatoirement</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>Les valeurs positives tournent dans le sens des aiguilles d&apos;une montre, les valeurs négatives dans le sens inverse.
La rotation par des multiplicateurs autres que 90° peut entraîner une perte de qualité.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horizontale</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Verticale</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Pivoter</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>Retourner</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Redimensionner l&apos;image</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Conserver le ratio</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Largeur :</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Hauteur :</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Pourcentage</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Autocollant</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Sélectionner</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Crayon</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Numéro</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Marqueur rectangle</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Marqueur ellipse</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Surligneur</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texte</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Flèche</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Flèche double</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Ligne</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Flou</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectangle</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Pointeur de numéro</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Autocollant</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Pixéliser</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Pointeur de texte</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Flèche de texte</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Flèche de nombre</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Dupliquer</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation type="unfinished">Zoom avant (%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation type="unfinished">Zoom arrière (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation type="unfinished">Réinitialiser le zoom (%1)</translation>
    </message>
</context>
</TS>
